@@ -1,5 +1,6 @@
 from typing import List, Optional
 from .schema import PlayerMove, Player
+from pathlib import Path
 
 
 class LogWriter:
@@ -22,6 +23,7 @@ class LogWriter:
 
     def write(self):
         formatted_moves = self.format_moves()
+        Path(self.path).mkdir(parents=True, exist_ok=True)
         with open(self.path, "w+") as log_file:
             log_file.writelines(formatted_moves)
             if self.winner is not None:
