@@ -21,13 +21,16 @@ def play_game(
         ..., help="The url of the bot for player 0"
     ),
     log_file: str = typer.Option(
-        default="./logs/game.log", help="The path to which log file should be written"
+        default="game.log", help="The path to which log file should be written"
     ),
     visualize: bool = typer.Option(
         default=False, help="Whether to print out board states and moves when running simulator"
     ),
     log_level: int = typer.Option(
         default=logging.WARNING, help="Logs level for simulator logs", show_default=True
+    ),
+    context: str = typer.Option(
+        default="", help="Context to add in logs when multiple matches are being run simultaneously"
     )
 ) -> GameResult:
     """
@@ -36,6 +39,7 @@ def play_game(
     """
     bot_data = [{}, {}]
     player_moves: List[PlayerMove] = []
+    print(log_level)
     logger = get_logger(__name__, level=log_level)
     game_simulator = Simulator(
         verbose=visualize, logging_level=log_level)
