@@ -30,9 +30,9 @@ class InvalidMovesMessage(str, Enum):
     HOME_ROW_ELIMINATION_FORBIDDEN = "Eliminations are forbidden in the home rows fo both player, i.e., row 0 and 4"
 
 
-class Coord(BaseModel):
-    x: int
-    y: int
+class Position(BaseModel):
+    row: int
+    col: int
 
     @validator("*")
     def validate_coordinates(cls, v):
@@ -42,15 +42,15 @@ class Coord(BaseModel):
         return v
 
     def __eq__(self, other: Any) -> bool:
-        return self.x == other.x and self.y == other.y
+        return self.row == other.row and self.col == other.col
 
 
 class Move(BaseModel):
-    src: Coord
-    dst: Coord
+    src: Position
+    dst: Position
 
     def __str__(self) -> str:
-        return f"Source: ({self.src.x}, {self.src.y})\nDest: ({self.dst.x}, {self.dst.y})"
+        return f"Source: ({self.src.row}, {self.src.col})\nDest: ({self.dst.row}, {self.dst.col})"
 
 
 class BotResponse(BaseModel):
